.. _install:

Installation
============

**lollipop** requries Python >= 2.6 or <= 3.6. It has no external dependencies other
than the Python standard library.

::

    $ pip install lollipop

Bleeding Edge
-------------

To get latest development version of lollipop, run

::

    $ pip install git+https://github.com/maximkulkin/lollipop.git
